@@ -15,7 +15,17 @@ gi_available_templates <-
     url <- glue::glue("{backend_url()}/api/list?format=json")
     res <- curl::curl_fetch_memory(url)
 
-    r <- jsonlite::fromJSON(rawToChar(res$content))
+    if (res$status_code != 200) {
+      stop(paste("http request failed with status code:"), res$status_code)
+    }
+
+    json_text <- rawToChar(res$content)
+
+    if (!jsonlite::validate(json_text)) {
+      stop("Invalid json file returned in gi_available_templates() function.")
+    }
+
+    r <- jsonlite::fromJSON(json_text)
 
     templates <- tolower(sort(purrr::map_chr(r, "name")))
     unname(templates)
