@@ -1,4 +1,7 @@
 test_that("no change in the gitignore file", {
+  skip_on_cran()
+  skip_if_offline()
+
   f <- file.path(tempdir(), ".gitignore")
   file.create(f)
 
@@ -14,6 +17,9 @@ test_that("no change in the gitignore file", {
 })
 
 test_that(".gitignore file can not be found", {
+  skip_on_cran()
+  skip_if_offline()
+
   f <- file.path(tempdir(), ".gitignore")
   unlink(f)
 
